==> dde-session-shell_5.5.34.tar.xz: BUILD/translations/dde-session-shell_bn.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bn" version="2.1">
<context>
    <name>ContentWidget</name>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="345"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="346"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="350"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="354"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="358"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="362"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="349"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="353"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="357"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="361"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="379"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="416"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="438"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="574"/>
        <source>Shut down</source>
        <translation>বন্ধ করুন</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="381"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="418"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="441"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="577"/>
        <source>Reboot</source>
        <translation>পুনঃরায় চালু করুন</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="383"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="580"/>
        <source>Suspend</source>
        <translation>সাময়িক ভাবে বন্ধ করুন</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="385"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="583"/>
        <source>Hibernate</source>
        <translation>হায়বারনেট</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="387"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="444"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="589"/>
        <source>Log out</source>
        <translation>লগ আউট করুন</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="439"/>
        <source>Are you sure you want to shut down?</source>
        <translation>আপনি কি নিশ্চিত যে, আপনি বন্ধ করতে চান?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="442"/>
        <source>Are you sure you want to reboot?</source>
        <translation>আপনি কি নিশ্চিত যে, আপনি পুনরায় চালু করতে চান?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="445"/>
        <source>Are you sure you want to log out?</source>
        <translation>আপনি কি নিশ্চিত যে, আপনি লগ আউট করতে চান?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="586"/>
        <source>Lock</source>
        <translation>লক করুন</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="593"/>
        <source>Switch user</source>
        <translation>ব্যবহারকারী পরিবর্তন করুন</translation>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <location filename="../src/libdde-auth/deepinauthframework.cpp" line="109"/>
        <source>Verify your fingerprint or password</source>
        <translation>একটি আঙ্গুলের ছাপ অথবা পাসওয়ার্ড যাচাই করুন</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="347"/>
        <source>Wrong Password</source>
        <translation>ভুল পাসওয়ার্ড</translation>
    </message>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="352"/>
        <source>The domain account or password is not correct. Please enter again.</source>
        <translation>ডোমেন অ্যাকাউন্ট বা পাসওয়ার্ড সঠিক নয়। দয়া করে আবার প্রবেশ করান।</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="88"/>
        <source>Cancel</source>
        <translation>বাতিল করুন</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="330"/>
        <source>Lock Screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="334"/>
        <source>Failed to lock screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="119"/>
        <source>Domain account</source>
        <translation>ডোমেন অ্যাকাউন্ট</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="269"/>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>আঙুলের ছাপ যাচাই করার সময় শেষ, দয়া করে হাত দিয়ে পাসওয়ার্ড প্রবেশ করান।</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="287"/>
        <source>Failed to match fingerprint</source>
        <translation>আঙুলের ছাপ মিলাতে ব্যর্থ হয়েছে</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="322"/>
        <source>Wrong Password</source>
        <translation>ভুল পাসওয়ার্ড</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
        <source>Cancel</source>
        <translation>বাতিল করুন</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="129"/>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>উপরে থাকা ব্যবহারকারীরা এখনও লগ ইন করে আছেন এবং বন্ধ হওয়ার কারণে ডেটা হারিয়ে যাবে, আপনি কি নিশ্চিত যে, আপনি বন্ধ করতে চান?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="133"/>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>উপরে থাকা ব্যবহারকারীরা এখনও লগ ইন করে আছেন এবং বন্ধ হওয়ার কারণে ডেটা হারিয়ে যাবে, আপনি কি নিশ্চিত যে আপনি পুনরায় চালু করতে চান?</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="29"/>
        <source>Shut down</source>
        <translation>বন্ধ করুন</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="101"/>
        <source>Reboot</source>
        <translation>পুনঃরায় চালু করুন</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="108"/>
        <source>Suspend</source>
        <translation>সাময়িক ভাবে বন্ধ করুন</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="115"/>
        <source>Hibernate</source>
        <translation>হায়বারনেট</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
        <source>Start system monitor</source>
        <translation>সিস্টেম মনিটর চালু করুন</translation>
    </message>
</context>
<context>
    <name>UserExpiredWidget</name>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="149"/>
        <source>Password expired, please change</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="153"/>
        <source>New password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="162"/>
        <source>Repeat password</source>
        <translation>পুনরায় পাসওয়ার্ড দিন</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="320"/>
        <source>Failed to change your password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="334"/>
        <source>Password too weak</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="342"/>
        <source>Please enter the new password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="348"/>
        <source>Please repeat the new password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="354"/>
        <source>Passwords do not match</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="189"/>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="191"/>
        <source>Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="226"/>
        <source>Enter your password to reboot</source>
        <translation>রিস্টার্ট করতে আপনার পাসওয়ার্ড প্রবেশ করান</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="229"/>
        <source>Enter your password to shut down</source>
        <translation>বন্ধ করতে আপনার পাসওয়ার্ড প্রবেশ করান</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="239"/>
        <source>Please enter the account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="246"/>
        <source>Please enter the password</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <location filename="../src/session-widgets/userloginwidget.cpp" line="319"/>
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
</TS>

==> dde-session-shell_6.0.21.tar.xz: BUILD/translations/dde-session-shell_bn.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bn">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>ভুল পাসওয়ার্ড</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>UKey is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your password has expired. Please change it.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChangePasswordWidget</name>
    <message>
        <source>Your password has expired. Please change it and log in again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save</source>
        <translation>সংরক্ষণ করুন</translation>
    </message>
    <message>
        <source>Old password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Repeat new password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password hint (Optional)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Passwords do not match</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New password should differ from the current one</source>
        <translation>নতুন পাসওয়ার্ডটি বর্তমান পাসওয়ার্ড হতে পৃথক হওয়া উচিত</translation>
    </message>
    <message>
        <source>Password changed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong password</source>
        <translation>ভুল পাসওয়ার্ড</translation>
    </message>
</context>
<context>
    <name>ControlWidget</name>
    <message>
        <source>Desktop Environment and Display Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keyboard Layout</source>
        <translation>কীবোর্ড লেআউট</translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power</source>
        <translation>পাওয়ার</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>ভুল পাসওয়ার্ড</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>বাতিল করুন</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>আঙুলের ছাপ যাচাই করার সময় শেষ, দয়া করে হাত দিয়ে পাসওয়ার্ড প্রবেশ করান।</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>আঙুলের ছাপ মিলাতে ব্যর্থ হয়েছে</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>বাতিল করুন</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>উপরে থাকা ব্যবহারকারীরা এখনও লগ ইন করে আছেন এবং বন্ধ হওয়ার কারণে ডেটা হারিয়ে যাবে, আপনি কি নিশ্চিত যে, আপনি বন্ধ করতে চান?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>উপরে থাকা ব্যবহারকারীরা এখনও লগ ইন করে আছেন এবং বন্ধ হওয়ার কারণে ডেটা হারিয়ে যাবে, আপনি কি নিশ্চিত যে আপনি পুনরায় চালু করতে চান?</translation>
    </message>
</context>
<context>
    <name>PasswordLevelWidget</name>
    <message>
        <source>Weak</source>
        <translation>দুর্বল</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>মধ্যম</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <source>Password cannot be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must have at least %1 characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must be no more than %1 characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more than %1 palindrome characters please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more than %1 monotonic characters please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more than %1 repeating characters please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not use common words and combinations as password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create a strong password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>It does not meet password rules</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>বন্ধ করুন</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>পুনঃরায় চালু করুন</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>সাময়িক ভাবে বন্ধ করুন</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>হায়বারনেট</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>লক করুন</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>লগ আউট করুন</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch user</source>
        <translation>ব্যবহারকারী পরিবর্তন করুন</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>সিস্টেম মনিটর চালু করুন</translation>
    </message>
</context>
<context>
    <name>UserListPopupWidget</name>
    <message>
        <source>Standard User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Administrator</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other Users</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VirtualKeyboardModule</name>
    <message>
        <source>Onboard</source>
        <translation>ওনবোর্ড</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shut down</source>
        <translation>বন্ধ করুন</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>পুনঃরায় চালু করুন</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>সাময়িক ভাবে বন্ধ করুন</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>হায়বারনেট</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>লগ আউট করুন</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>আপনি কি নিশ্চিত যে, আপনি বন্ধ করতে চান?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>আপনি কি নিশ্চিত যে, আপনি পুনরায় চালু করতে চান?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>আপনি কি নিশ্চিত যে, আপনি লগ আউট করতে চান?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
